/***********************************************************************
 *                copyright 2001, Amoco Production Company             *
 *                            All Rights Reserved                      *
 *                    an affiliate of BP America Inc.                  *
 ***********************************************************************/
#include <stdio.h>
#include <sys/types.h>
#include <sys/wait.h>

int waiton(pid) /* get exit status of child pid */
int pid;
{
	int code, ret;

	while ((ret = wait(&code)) != pid && ret > 0)
		;

	if (ret >= 0)	
		return (!(code & 0377) ? code >> 8 : code);

	perror("waiton");

	return ret;

}
